@@ -2,8 +2,6 @@ package eu.veldsoft.complica4;
 
 import android.app.Activity;
 import android.os.Bundle;
-import android.view.Menu;
-import android.view.MenuItem;
 
 public class HelpActivity extends Activity {
 
